@@ -43,7 +43,7 @@ class DetectionParse(BaseParse):
         object_struct = Struct("LocalObjectEntry")
         object_struct.set_arg("cdom")  # object struct有一个形参 cdom
         sample_struct = Struct("ObjectDetectionSample")
-        sample_struct.set_arg("cdom") # sample struct 有一个形参 cdom
+        sample_struct.set_arg("cdom")  # sample struct 有一个形参 cdom
         media_field = Field("media", field_type="media")
         sample_struct.add_field(media_field)  # 添加图像field
         sample_container = DataSample(sample_struct, self._class_domain)
@@ -119,6 +119,6 @@ class DetectionParse(BaseParse):
             sample_struct.add_field(annotation_field)  # 添加annotation field
             if annotation_option_flag:
                 sample_struct.set_optional("annotations")
-            return (object_struct, sample_struct), sample_container
+            return (object_struct, sample_struct), [], sample_container
         else:
-            return (sample_struct,), [self._class_domain], sample_container
\ No newline at end of file
+            return (sample_struct,), [self._class_domain, self._class_domain.parent_domain], sample_container
